function [W,C]=hexag(N,M)

%hexag(N,M) Produces a weight matrix for a regular hexagonal lattice of dimensions NxM,
%          according to the first order adjacency criterion.
%          W=HEXAG(N,M) will produce an N*M binary matrix .
%          [W,C]=hexag(N,M) also stores the coordinates of the hexagons 

W=zeros(N*M);
COUNT=0;
MAX=N*M;
for i=1:N
   for j=1:M
      
      COUNT=COUNT+1;
      L=COUNT-1;
      R=COUNT+1;

      if j>1
          W(COUNT,L)=1;
      end
      
      if j<M
          W(COUNT,R)=1;
      end
      
      if mod(i,2)==1 & i>1       %Odd rows not first row
          W(COUNT,COUNT-M)=1;    % All have upper right
          if j>1
              W(COUNT,COUNT-M-1)=1;   % All but first column has upper left
          end;
      end
      
      if mod(i,2)==1 & i<N  %Odd rows not last row
          W(COUNT,COUNT+M)=1; % All have lower right
          if j>1
              W(COUNT,COUNT+M-1)=1; %All but first column have lower left
          end;
      end;
      
      if mod(i,2)==0               %Even rows
          W(COUNT,COUNT-M)=1;    % All have upper left
          if j<M
              W(COUNT,COUNT-M+1)=1;   % All but last column has upper right
          end;
      end
      
      if mod(i,2)==0 & i<N  %Odd rows not last row
          W(COUNT,COUNT+M)=1; % All have lower left
          if j<M
              W(COUNT,COUNT+M+1)=1; %All but last column have lower right
          end;
      end;
          
       
      
   end
end
   
%Obtain coordinates
x=(1+sqrt(7))/4;y=x-1/2;
count=0;
for i=N:-1:1
    for j=1:M
        count=count+1;
        C(count,2)=(i-1)*(y+1)+(y+1/2);
        if rem(i,2)==0 %if even row
            C(count,1)=2*x+(j-1)*2*x;
        else %if odd row
            C(count,1)=x+(j-1)*2*x;              
        end
    end
end
end

